# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scheduling/scheduling.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='scheduling/scheduling.proto',
  package='chaosplatform.scheduling',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1bscheduling/scheduling.proto\x12\x18\x63haosplatform.scheduling\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xea\x03\n\x08Schedule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x04 \x01(\t\x12\x15\n\rexperiment_id\x18\x05 \x01(\t\x12\x10\n\x08token_id\x18\x06 \x01(\t\x12\x0e\n\x06job_id\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x10\n\x08interval\x18\t \x01(\x02\x12.\n\ncreated_on\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x61\x63tive_from\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x61\x63tive_until\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x07results\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08settings\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\rconfiguration\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07secrets\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\".\n\nGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"@\n\x08GetReply\x12\x34\n\x08schedule\x18\x01 \x01(\x0b\x32\".chaosplatform.scheduling.Schedule\"3\n\x0eGetManyRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"E\n\x0cGetManyReply\x12\x35\n\tschedules\x18\x01 \x03(\x0b\x32\".chaosplatform.scheduling.Schedule\"9\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"G\n\x0eGetByUserReply\x12\x35\n\tschedules\x18\x01 \x03(\x0b\x32\".chaosplatform.scheduling.Schedule\"7\n\x0fGetByOrgRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"F\n\rGetByOrgReply\x12\x35\n\tschedules\x18\x01 \x03(\x0b\x32\".chaosplatform.scheduling.Schedule\"C\n\x15GetByWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"L\n\x13GetByWorkspaceReply\x12\x35\n\tschedules\x18\x01 \x03(\x0b\x32\".chaosplatform.scheduling.Schedule\"E\n\x16GetByExperimentRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"M\n\x14GetByExperimentReply\x12\x35\n\tschedules\x18\x01 \x03(\x0b\x32\".chaosplatform.scheduling.Schedule\"A\n\x17GetByAccessTokenRequest\x12\x10\n\x08token_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"M\n\x15GetByAccessTokenReply\x12\x34\n\x08schedule\x18\x01 \x01(\x0b\x32\".chaosplatform.scheduling.Schedule2\xe3\x05\n\x11SchedulingService\x12O\n\x03Get\x12$.chaosplatform.scheduling.GetRequest\x1a\".chaosplatform.scheduling.GetReply\x12[\n\x07GetMany\x12(.chaosplatform.scheduling.GetManyRequest\x1a&.chaosplatform.scheduling.GetManyReply\x12\x61\n\tGetByUser\x12*.chaosplatform.scheduling.GetByUserRequest\x1a(.chaosplatform.scheduling.GetByUserReply\x12^\n\x08GetByOrg\x12).chaosplatform.scheduling.GetByOrgRequest\x1a\'.chaosplatform.scheduling.GetByOrgReply\x12p\n\x0eGetByWorkspace\x12/.chaosplatform.scheduling.GetByWorkspaceRequest\x1a-.chaosplatform.scheduling.GetByWorkspaceReply\x12s\n\x0fGetByExperiment\x12\x30.chaosplatform.scheduling.GetByExperimentRequest\x1a..chaosplatform.scheduling.GetByExperimentReply\x12v\n\x10GetByAccessToken\x12\x31.chaosplatform.scheduling.GetByAccessTokenRequest\x1a/.chaosplatform.scheduling.GetByAccessTokenReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_SCHEDULE = _descriptor.Descriptor(
  name='Schedule',
  full_name='chaosplatform.scheduling.Schedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.scheduling.Schedule.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.scheduling.Schedule.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.scheduling.Schedule.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.scheduling.Schedule.workspace_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='chaosplatform.scheduling.Schedule.experiment_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_id', full_name='chaosplatform.scheduling.Schedule.token_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='chaosplatform.scheduling.Schedule.job_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='chaosplatform.scheduling.Schedule.status', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='chaosplatform.scheduling.Schedule.interval', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_on', full_name='chaosplatform.scheduling.Schedule.created_on', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_from', full_name='chaosplatform.scheduling.Schedule.active_from', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_until', full_name='chaosplatform.scheduling.Schedule.active_until', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='chaosplatform.scheduling.Schedule.results', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='chaosplatform.scheduling.Schedule.settings', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='chaosplatform.scheduling.Schedule.configuration', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secrets', full_name='chaosplatform.scheduling.Schedule.secrets', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=611,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='chaosplatform.scheduling.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.scheduling.GetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.scheduling.GetRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=659,
)


_GETREPLY = _descriptor.Descriptor(
  name='GetReply',
  full_name='chaosplatform.scheduling.GetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='chaosplatform.scheduling.GetReply.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=725,
)


_GETMANYREQUEST = _descriptor.Descriptor(
  name='GetManyRequest',
  full_name='chaosplatform.scheduling.GetManyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='chaosplatform.scheduling.GetManyRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.scheduling.GetManyRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=778,
)


_GETMANYREPLY = _descriptor.Descriptor(
  name='GetManyReply',
  full_name='chaosplatform.scheduling.GetManyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='chaosplatform.scheduling.GetManyReply.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=849,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.scheduling.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.scheduling.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.scheduling.GetByUserRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=908,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.scheduling.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='chaosplatform.scheduling.GetByUserReply.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=981,
)


_GETBYORGREQUEST = _descriptor.Descriptor(
  name='GetByOrgRequest',
  full_name='chaosplatform.scheduling.GetByOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.scheduling.GetByOrgRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.scheduling.GetByOrgRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1038,
)


_GETBYORGREPLY = _descriptor.Descriptor(
  name='GetByOrgReply',
  full_name='chaosplatform.scheduling.GetByOrgReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='chaosplatform.scheduling.GetByOrgReply.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1040,
  serialized_end=1110,
)


_GETBYWORKSPACEREQUEST = _descriptor.Descriptor(
  name='GetByWorkspaceRequest',
  full_name='chaosplatform.scheduling.GetByWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.scheduling.GetByWorkspaceRequest.workspace_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.scheduling.GetByWorkspaceRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1179,
)


_GETBYWORKSPACEREPLY = _descriptor.Descriptor(
  name='GetByWorkspaceReply',
  full_name='chaosplatform.scheduling.GetByWorkspaceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='chaosplatform.scheduling.GetByWorkspaceReply.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1257,
)


_GETBYEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='GetByExperimentRequest',
  full_name='chaosplatform.scheduling.GetByExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='chaosplatform.scheduling.GetByExperimentRequest.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.scheduling.GetByExperimentRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1259,
  serialized_end=1328,
)


_GETBYEXPERIMENTREPLY = _descriptor.Descriptor(
  name='GetByExperimentReply',
  full_name='chaosplatform.scheduling.GetByExperimentReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='chaosplatform.scheduling.GetByExperimentReply.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1330,
  serialized_end=1407,
)


_GETBYACCESSTOKENREQUEST = _descriptor.Descriptor(
  name='GetByAccessTokenRequest',
  full_name='chaosplatform.scheduling.GetByAccessTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token_id', full_name='chaosplatform.scheduling.GetByAccessTokenRequest.token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.scheduling.GetByAccessTokenRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1474,
)


_GETBYACCESSTOKENREPLY = _descriptor.Descriptor(
  name='GetByAccessTokenReply',
  full_name='chaosplatform.scheduling.GetByAccessTokenReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='chaosplatform.scheduling.GetByAccessTokenReply.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1553,
)

_SCHEDULE.fields_by_name['created_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULE.fields_by_name['active_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULE.fields_by_name['active_until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULE.fields_by_name['results'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SCHEDULE.fields_by_name['settings'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SCHEDULE.fields_by_name['configuration'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SCHEDULE.fields_by_name['secrets'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GETREPLY.fields_by_name['schedule'].message_type = _SCHEDULE
_GETMANYREPLY.fields_by_name['schedules'].message_type = _SCHEDULE
_GETBYUSERREPLY.fields_by_name['schedules'].message_type = _SCHEDULE
_GETBYORGREPLY.fields_by_name['schedules'].message_type = _SCHEDULE
_GETBYWORKSPACEREPLY.fields_by_name['schedules'].message_type = _SCHEDULE
_GETBYEXPERIMENTREPLY.fields_by_name['schedules'].message_type = _SCHEDULE
_GETBYACCESSTOKENREPLY.fields_by_name['schedule'].message_type = _SCHEDULE
DESCRIPTOR.message_types_by_name['Schedule'] = _SCHEDULE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetReply'] = _GETREPLY
DESCRIPTOR.message_types_by_name['GetManyRequest'] = _GETMANYREQUEST
DESCRIPTOR.message_types_by_name['GetManyReply'] = _GETMANYREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
DESCRIPTOR.message_types_by_name['GetByOrgRequest'] = _GETBYORGREQUEST
DESCRIPTOR.message_types_by_name['GetByOrgReply'] = _GETBYORGREPLY
DESCRIPTOR.message_types_by_name['GetByWorkspaceRequest'] = _GETBYWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['GetByWorkspaceReply'] = _GETBYWORKSPACEREPLY
DESCRIPTOR.message_types_by_name['GetByExperimentRequest'] = _GETBYEXPERIMENTREQUEST
DESCRIPTOR.message_types_by_name['GetByExperimentReply'] = _GETBYEXPERIMENTREPLY
DESCRIPTOR.message_types_by_name['GetByAccessTokenRequest'] = _GETBYACCESSTOKENREQUEST
DESCRIPTOR.message_types_by_name['GetByAccessTokenReply'] = _GETBYACCESSTOKENREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Schedule = _reflection.GeneratedProtocolMessageType('Schedule', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULE,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.Schedule)
  ))
_sym_db.RegisterMessage(Schedule)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetReply = _reflection.GeneratedProtocolMessageType('GetReply', (_message.Message,), dict(
  DESCRIPTOR = _GETREPLY,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetReply)
  ))
_sym_db.RegisterMessage(GetReply)

GetManyRequest = _reflection.GeneratedProtocolMessageType('GetManyRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREQUEST,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetManyRequest)
  ))
_sym_db.RegisterMessage(GetManyRequest)

GetManyReply = _reflection.GeneratedProtocolMessageType('GetManyReply', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREPLY,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetManyReply)
  ))
_sym_db.RegisterMessage(GetManyReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)

GetByOrgRequest = _reflection.GeneratedProtocolMessageType('GetByOrgRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREQUEST,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByOrgRequest)
  ))
_sym_db.RegisterMessage(GetByOrgRequest)

GetByOrgReply = _reflection.GeneratedProtocolMessageType('GetByOrgReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREPLY,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByOrgReply)
  ))
_sym_db.RegisterMessage(GetByOrgReply)

GetByWorkspaceRequest = _reflection.GeneratedProtocolMessageType('GetByWorkspaceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREQUEST,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByWorkspaceRequest)
  ))
_sym_db.RegisterMessage(GetByWorkspaceRequest)

GetByWorkspaceReply = _reflection.GeneratedProtocolMessageType('GetByWorkspaceReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREPLY,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByWorkspaceReply)
  ))
_sym_db.RegisterMessage(GetByWorkspaceReply)

GetByExperimentRequest = _reflection.GeneratedProtocolMessageType('GetByExperimentRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYEXPERIMENTREQUEST,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByExperimentRequest)
  ))
_sym_db.RegisterMessage(GetByExperimentRequest)

GetByExperimentReply = _reflection.GeneratedProtocolMessageType('GetByExperimentReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYEXPERIMENTREPLY,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByExperimentReply)
  ))
_sym_db.RegisterMessage(GetByExperimentReply)

GetByAccessTokenRequest = _reflection.GeneratedProtocolMessageType('GetByAccessTokenRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYACCESSTOKENREQUEST,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByAccessTokenRequest)
  ))
_sym_db.RegisterMessage(GetByAccessTokenRequest)

GetByAccessTokenReply = _reflection.GeneratedProtocolMessageType('GetByAccessTokenReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYACCESSTOKENREPLY,
  __module__ = 'scheduling.scheduling_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.scheduling.GetByAccessTokenReply)
  ))
_sym_db.RegisterMessage(GetByAccessTokenReply)



_SCHEDULINGSERVICE = _descriptor.ServiceDescriptor(
  name='SchedulingService',
  full_name='chaosplatform.scheduling.SchedulingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1556,
  serialized_end=2295,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='chaosplatform.scheduling.SchedulingService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMany',
    full_name='chaosplatform.scheduling.SchedulingService.GetMany',
    index=1,
    containing_service=None,
    input_type=_GETMANYREQUEST,
    output_type=_GETMANYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByUser',
    full_name='chaosplatform.scheduling.SchedulingService.GetByUser',
    index=2,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByOrg',
    full_name='chaosplatform.scheduling.SchedulingService.GetByOrg',
    index=3,
    containing_service=None,
    input_type=_GETBYORGREQUEST,
    output_type=_GETBYORGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByWorkspace',
    full_name='chaosplatform.scheduling.SchedulingService.GetByWorkspace',
    index=4,
    containing_service=None,
    input_type=_GETBYWORKSPACEREQUEST,
    output_type=_GETBYWORKSPACEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByExperiment',
    full_name='chaosplatform.scheduling.SchedulingService.GetByExperiment',
    index=5,
    containing_service=None,
    input_type=_GETBYEXPERIMENTREQUEST,
    output_type=_GETBYEXPERIMENTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByAccessToken',
    full_name='chaosplatform.scheduling.SchedulingService.GetByAccessToken',
    index=6,
    containing_service=None,
    input_type=_GETBYACCESSTOKENREQUEST,
    output_type=_GETBYACCESSTOKENREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCHEDULINGSERVICE)

DESCRIPTOR.services_by_name['SchedulingService'] = _SCHEDULINGSERVICE

# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
import io
import re
from os.path import abspath, dirname, join, normpath
import sys

from setuptools import find_packages, setup


def get_version_from_package() -> str:
    """
    Read the package version from the source without importing it.
    """
    path = join(dirname(__file__), "chaosplt_grpc/__init__.py")
    path = normpath(abspath(path))
    with open(path) as f:
        for line in f:
            if line.startswith("__version__"):
                token, version = line.split(" = ", 1)
                version = version.replace("'", "").strip()
                return version


def read(*names, **kwargs) -> str:
    return io.open(
        join(dirname(__file__), *names),
        encoding=kwargs.get('encoding', 'utf8')
    ).read()


needs_pytest = set(['pytest', 'test']).intersection(sys.argv)
pytest_runner = ['pytest_runner'] if needs_pytest else []
test_require = []
with io.open('requirements-dev.txt') as f:
    test_require = [l.strip() for l in f if not l.startswith('#')]

install_require = []
with io.open('requirements.txt') as f:
    install_require = [l.strip() for l in f if not l.startswith('#')]


setup(
    name='chaosplatform-grpc',
    version=get_version_from_package(),
    license='Apache Software License 2.0',
    description='Library of gRPC client and server for Chaos Platform services',
    long_description=read("README.md"),
    long_description_content_type='text/markdown',
    author='ChaosIQ',
    author_email='contact@chaosiq.io',
    url='https://github.com/chaostoolkit/chaosplatform-grpc',
    packages=find_packages(),
    include_package_data=True,
    install_requires=install_require,
    tests_require=test_require,
    setup_requires=pytest_runner,
    zip_safe=False,
    python_requires='>=3.6.*',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython'
    ]
)



from typing import List

from grpc import Channel

from .scheduling_pb2_grpc import SchedulingServiceStub
from .message import Schedule, GetRequest, GetManyRequest, \
    GetByUserRequest, GetByOrgRequest, GetByWorkspaceRequest, \
    GetByExperimentRequest

__all__ = ["get_scheduling", "get_schedulings", "get_by_user",
           "get_by_org", "get_by_workspace", "get_by_experiment"]


def get_scheduling(channel: Channel, scheduling_id: str,
                   with_payload: bool = False) -> Schedule:
    """
    Get an execution
    """
    stub = SchedulingServiceStub(channel)
    response = stub.Get(
        GetRequest(id=scheduling_id, with_payload=with_payload))
    return response.workspace


def get_schedulings(channel: Channel, scheduling_ids: List[str],
                    with_payload: bool = False) -> List[Schedule]:
    """
    Get many executions
    """
    stub = SchedulingServiceStub(channel)
    response = stub.GetMany(
        GetManyRequest(ids=scheduling_ids, with_payload=with_payload))
    return response.workspaces


def get_by_user(channel: Channel, user_id: str,
                with_payload: bool = False) -> List[Schedule]:
    """
    Get schedulings of an user
    """
    stub = SchedulingServiceStub(channel)
    response = stub.GetByUser(
        GetByUserRequest(user_id=user_id, with_payload=with_payload))
    return response.schedules


def get_by_org(channel: Channel, org_id: str,
               with_payload: bool = False) -> List[Schedule]:
    """
    Get schedulings of an organization
    """
    stub = SchedulingServiceStub(channel)
    response = stub.GetByOrg(
        GetByOrgRequest(org_id=org_id, with_payload=with_payload))
    return response.schedules


def get_by_workspace(channel: Channel, workspace_id: str,
                     with_payload: bool = False) -> List[Schedule]:
    """
    Get schedulings of a workspace
    """
    stub = SchedulingServiceStub(channel)
    response = stub.GetByWorkspace(
        GetByWorkspaceRequest(
            workspace_id=workspace_id, with_payload=with_payload))
    return response.schedules


def get_by_experiment(channel: Channel, experiment_id: str,
                      with_payload: bool = False) -> List[Schedule]:
    """
    Get schedulings of an experiment
    """
    stub = SchedulingServiceStub(channel)
    response = stub.GetByExperiment(
        GetByExperimentRequest(
            experiment_id=experiment_id, with_payload=with_payload))
    return response.schedules



from typing import List, NoReturn

import grpc
from grpc import Channel

from .auth_pb2_grpc import AuthServiceStub
from .message import AccessToken, CreateRequest, CreateReply, \
    DeleteRequest, DeleteReply, GetRequest, GetReply, GetByNameRequest, \
    GetByNameReply, GetByUserRequest, GetByUserReply, RevokeRequest, \
    RevokeReply, GetByJtiRequest, GetByJtiReply, GetByWorkspaceRequest, \
    GetByOrgRequest

__all__ = ["create_access_token", "remove_access_token", "get_access_token",
           "get_access_token_by_name", "get_access_tokens_by_user",
           "revoke_access_token", "get_access_token_by_jti", "get_by_org",
           "get_by_workspace"]


def create_access_token(channel: Channel, user_id: str,
                        name: str) -> AccessToken:
    """
    Create an access token.
    """
    stub = AuthServiceStub(channel)
    context = CreateRequest(user_id=user_id, name=name)
    response = stub.Create(context)
    return response.token


def remove_access_token(channel: Channel, user_id: str,
                        token_id: str) -> NoReturn:
    """
    Remove the token from the storage.
    """
    stub = AuthServiceStub(channel)
    stub.Remove(DeleteRequest(id=token_id, user_id=user_id))


def revoke_access_token(channel: Channel, user_id: str,
                        token_id: str) -> NoReturn:
    """
    Revoke the token.
    """
    stub = AuthServiceStub(channel)
    stub.Remove(RevokeRequest(id=token_id, user_id=user_id))


def get_access_token_by_name(channel, user_id: str, name: str) -> AccessToken:
    """
    Get the token by name for a given user
    """
    stub = AuthServiceStub(channel)
    response = stub.GetByName(name=name, user_id=user_id)
    return response.token


def get_access_tokens_by_user(channel, user_id: str) -> List[AccessToken]:
    """
    Get all tokens of a given user
    """
    stub = AuthServiceStub(channel)
    response = stub.GetByUser(user_id=user_id)
    return response.tokens


def get_access_token(channel, token_id: str) -> AccessToken:
    """
    Get an access token
    """
    stub = AuthServiceStub(channel)
    response = stub.Get(token_id=token_id)
    return response.token


def get_access_token_by_jti(channel, user_id: str, jti: str) -> AccessToken:
    """
    Get a token by its jti
    """
    stub = AuthServiceStub(channel)
    response = stub.GetByJti(user_id=user_id, jti=jti)
    return response.token


def get_by_org(channel, org_id: str) -> List[AccessToken]:
    """
    Get all tokens for an organization
    """
    stub = AuthServiceStub(channel)
    response = stub.GetByOrg(org_id=org_id)
    return response.tokens


def get_by_workspace(channel, workspace_id: str) -> List[AccessToken]:
    """
    Get all tokens for an organization
    """
    stub = AuthServiceStub(channel)
    response = stub.GetByWorkspace(workspace_id=workspace_id)
    return response.tokens



from typing import List, NoReturn

from grpc import Server

from .organization_pb2_grpc import add_OrganizationServiceServicer_to_server, \
    OrganizationServiceServicer
from .message import CreateRequest, CreateReply, DeleteRequest, DeleteReply, \
    GetByUserRequest, GetByUserReply, Organization, GetRequest, GetReply, \
    GetManyRequest, GetManyReply

__all__ = ["OrganizationService", "register_organization_service"]


class OrganizationService(OrganizationServiceServicer):
    def Create(self, request: CreateRequest, context) -> CreateReply:
        org = self.create_organization(request.name, request.user_id)
        return CreateReply(org=org)

    def Delete(self, request: DeleteRequest, context) -> DeleteReply:
        self.delete_organization(request.id)
        return DeleteReply()

    def ByUser(self, request: GetByUserRequest, context) -> GetByUserReply:
        orgs = self.get_organizations_for_user(request.user_id)
        return GetByUserReply(organizations=orgs)

    def Get(self, request: GetRequest, context) -> GetReply:
        org = self.get_organization(request.id)
        return GetReply(org=org)

    def GetMany(self, request: GetManyRequest, context) -> GetManyReply:
        orgs = self.get_organizations(request.ids)
        return GetManyReply(orgs=orgs)

    def delete_organization(self, user_id: str, name: str) -> NoReturn:
        raise NotImplementedError()

    def create_organization(self, user_id: str, name: str) -> Organization:
        raise NotImplementedError()

    def get_organization_for_user(self, user_id: str) -> List[Organization]:
        raise NotImplementedError()

    def get_organization(self, org_id: str) -> Organization:
        raise NotImplementedError()

    def get_organizations(self, org_ids: List[str]) -> List[Organization]:
        raise NotImplementedError()


def register_organization_service(service: OrganizationService,
                                  server: Server):
    """
    Register an organization service with the provided gRPC server.
    """
    add_OrganizationServiceServicer_to_server(service, server)



from typing import List, NoReturn

import grpc
from grpc import Channel, Server

from .auth_pb2_grpc import add_AuthServiceServicer_to_server, \
    AuthServiceServicer
from .message import AccessToken, CreateRequest, CreateReply, \
    DeleteRequest, DeleteReply, GetRequest, GetReply, GetByNameRequest, \
    GetByNameReply, GetByUserRequest, GetByUserReply, RevokeRequest, \
    RevokeReply, GetByJtiRequest, GetByJtiReply, GetByWorkspaceRequest, \
    GetByOrgRequest, GetByWorkspaceReply, GetByOrgReply

__all__ = ["AuthService", "register_auth_service"]


class AuthService(AuthServiceServicer):
    def Create(self, request: CreateRequest, context) -> CreateReply:
        token = self.create_access_token(request.user_id, request.name)
        return CreateReply(token=token)

    def Delete(self, request: DeleteRequest, context) -> DeleteReply:
        self.delete_access_token(request.user_id, request.id)
        return DeleteReply()

    def Revoke(self, request: RevokeRequest, context) -> DeleteReply:
        self.revoke_access_token(request.user_id, request.id)
        return RevokeReply()

    def GetByUser(self, request: GetRequest, context) -> GetReply:
        token = self.get(request.id)
        return GetReply(token=token)

    def GetByName(self, request: GetByNameRequest, context) -> GetByNameReply:
        token = self.get_by_name(request.user_id, request.name)
        return GetByNameReply(token=token)

    def GetByJti(self, request: GetByJtiRequest, context) -> GetByJtiReply:
        tokens = self.get_by_jti(request.user_id, request.jti)
        return GetByJtiReply(tokens=tokens)

    def GetByOrg(self, request: GetByOrgRequest, context) -> GetByOrgReply:
        tokens = self.get_by_org(request.org_id)
        return GetByOrgReply(tokens=tokens)

    def GetByWorkspace(self, request: GetByOrgRequest,
                       context) -> GetByWorkspaceReply:
        tokens = self.get_by_workspace(request.workspace_id)
        return GetByWorkspaceReply(tokens=tokens)

    def create_access_token(self, user_id: str, name: str) -> AccessToken:
        raise NotImplementedError()

    def delete_access_token(self, user_id: str, token_id: str) -> NoReturn:
        raise NotImplementedError()

    def revoke_access_token(self, user_id: str, token_id: str) -> NoReturn:
        raise NotImplementedError()

    def get_by_name(self, user_id: str, name: str) -> AccessToken:
        raise NotImplementedError()

    def get_by_user(self, user_id: str) -> List[AccessToken]:
        raise NotImplementedError()

    def get_by_jti(self, user_id: str, jti: str) -> AccessToken:
        raise NotImplementedError()

    def get(self, token_id: str) -> AccessToken:
        raise NotImplementedError()

    def get_by_org(self, org_id: str) -> List[AccessToken]:
        raise NotImplementedError()

    def get_by_workspace(self, workspace_id: str) -> List[AccessToken]:
        raise NotImplementedError()


def register_auth_service(service: AuthService, server: Server):
    """
    Register the given authentication service with the provided gRPC server.
    """
    add_AuthServiceServicer_to_server(service, server)



from datetime import datetime
from typing import Any, List, NoReturn
from uuid import UUID


import grpc
from grpc import Channel
import simplejson as json

from .scheduler_pb2_grpc import SchedulerServiceStub
from .message import Schedule, ScheduleRequest, ScheduleReply, \
    CancelRequest, CancelReply

__all__ = ["schedule_experiment", "cancel_experiment"]


def schedule_experiment(channel: Channel, schedule_id: UUID, user_id: UUID,
                        org_id: UUID, workspace_id: UUID, experiment_id: UUID,
                        token_id: UUID, token: str, scheduled: datetime,
                        experiment: Any, interval: int = None,
                        repeat: int = None, cron: str = None,
                        settings: Any = None, configuration: Any = None,
                        secrets: Any = None) -> str:
    """
    Schedule an experiment to be executed.
    """
    settings = json.dumps(settings) if settings is not None else None
    configuration = json.dumps(configuration) if \
        configuration is not None else None
    secrets = json.dumps(secrets) if secrets is not None else None
    experiment = json.dumps(experiment) if experiment is not None else None

    stub = SchedulerServiceStub(channel)
    response = stub.Schedule(ScheduleRequest(
        schedule=Schedule(
            schedule_id=str(schedule_id), user_id=str(user_id),
            org_id=str(org_id),
            workspace_id=str(workspace_id), experiment_id=str(experiment_id),
            token_id=str(token_id), token=token,
            scheduled="{}Z".format(scheduled.isoformat('T')),
            experiment=experiment, interval=interval, repeat=repeat, cron=cron,
            settings=settings, configuration=configuration, secrets=secrets)))
    return response.job_id


def cancel_experiment(channel: Channel, job_id: str) -> NoReturn:
    """
    Cancel an experiment's execution.
    """
    stub = SchedulerServiceStub(channel)
    stub.Cancel(CancelRequest(job_id=job_id))



from .scheduling_pb2 import Schedule, GetReply, GetManyRequest, \
    GetManyReply, GetRequest, GetByUserRequest, GetByUserReply, \
    GetByOrgRequest, GetByOrgReply, GetByWorkspaceRequest, \
    GetByWorkspaceReply, GetByExperimentRequest, GetByExperimentReply



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: registration/registration.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='registration/registration.proto',
  package='chaosplatform.registration',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1fregistration/registration.proto\x12\x1a\x63haosplatform.registration\"\x8c\x01\n\x0cRegistration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x18\n\x10is_authenticated\x18\x05 \x01(\x08\x12\x11\n\tis_active\x18\x06 \x01(\x08\x12\x14\n\x0cis_anonymous\x18\x07 \x01(\x08\">\n\rCreateRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"M\n\x0b\x43reateReply\x12>\n\x0cregistration\x18\x01 \x01(\x0b\x32(.chaosplatform.registration.Registration\"\x1b\n\rDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\r\n\x0b\x44\x65leteReply\"\x1c\n\x0eGetByIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\"N\n\x0cGetByIdReply\x12>\n\x0cregistration\x18\x01 \x01(\x0b\x32(.chaosplatform.registration.Registration2\xb2\x02\n\x13RegistrationService\x12\\\n\x06\x43reate\x12).chaosplatform.registration.CreateRequest\x1a\'.chaosplatform.registration.CreateReply\x12\\\n\x06\x44\x65lete\x12).chaosplatform.registration.DeleteRequest\x1a\'.chaosplatform.registration.DeleteReply\x12_\n\x07GetById\x12*.chaosplatform.registration.GetByIdRequest\x1a(.chaosplatform.registration.GetByIdReplyb\x06proto3')
)




_REGISTRATION = _descriptor.Descriptor(
  name='Registration',
  full_name='chaosplatform.registration.Registration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.registration.Registration.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.registration.Registration.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.registration.Registration.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='chaosplatform.registration.Registration.email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_authenticated', full_name='chaosplatform.registration.Registration.is_authenticated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='chaosplatform.registration.Registration.is_active', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_anonymous', full_name='chaosplatform.registration.Registration.is_anonymous', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=204,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='chaosplatform.registration.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.registration.CreateRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.registration.CreateRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='chaosplatform.registration.CreateRequest.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=268,
)


_CREATEREPLY = _descriptor.Descriptor(
  name='CreateReply',
  full_name='chaosplatform.registration.CreateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='registration', full_name='chaosplatform.registration.CreateReply.registration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=347,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='chaosplatform.registration.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.registration.DeleteRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=376,
)


_DELETEREPLY = _descriptor.Descriptor(
  name='DeleteReply',
  full_name='chaosplatform.registration.DeleteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=391,
)


_GETBYIDREQUEST = _descriptor.Descriptor(
  name='GetByIdRequest',
  full_name='chaosplatform.registration.GetByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.registration.GetByIdRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=421,
)


_GETBYIDREPLY = _descriptor.Descriptor(
  name='GetByIdReply',
  full_name='chaosplatform.registration.GetByIdReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='registration', full_name='chaosplatform.registration.GetByIdReply.registration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=501,
)

_CREATEREPLY.fields_by_name['registration'].message_type = _REGISTRATION
_GETBYIDREPLY.fields_by_name['registration'].message_type = _REGISTRATION
DESCRIPTOR.message_types_by_name['Registration'] = _REGISTRATION
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateReply'] = _CREATEREPLY
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteReply'] = _DELETEREPLY
DESCRIPTOR.message_types_by_name['GetByIdRequest'] = _GETBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetByIdReply'] = _GETBYIDREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Registration = _reflection.GeneratedProtocolMessageType('Registration', (_message.Message,), dict(
  DESCRIPTOR = _REGISTRATION,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.Registration)
  ))
_sym_db.RegisterMessage(Registration)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateReply = _reflection.GeneratedProtocolMessageType('CreateReply', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREPLY,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.CreateReply)
  ))
_sym_db.RegisterMessage(CreateReply)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteReply = _reflection.GeneratedProtocolMessageType('DeleteReply', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREPLY,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.DeleteReply)
  ))
_sym_db.RegisterMessage(DeleteReply)

GetByIdRequest = _reflection.GeneratedProtocolMessageType('GetByIdRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYIDREQUEST,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.GetByIdRequest)
  ))
_sym_db.RegisterMessage(GetByIdRequest)

GetByIdReply = _reflection.GeneratedProtocolMessageType('GetByIdReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYIDREPLY,
  __module__ = 'registration.registration_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.registration.GetByIdReply)
  ))
_sym_db.RegisterMessage(GetByIdReply)



_REGISTRATIONSERVICE = _descriptor.ServiceDescriptor(
  name='RegistrationService',
  full_name='chaosplatform.registration.RegistrationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=504,
  serialized_end=810,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='chaosplatform.registration.RegistrationService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='chaosplatform.registration.RegistrationService.Delete',
    index=1,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetById',
    full_name='chaosplatform.registration.RegistrationService.GetById',
    index=2,
    containing_service=None,
    input_type=_GETBYIDREQUEST,
    output_type=_GETBYIDREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_REGISTRATIONSERVICE)

DESCRIPTOR.services_by_name['RegistrationService'] = _REGISTRATIONSERVICE

# @@protoc_insertion_point(module_scope)



from typing import NoReturn

import grpc
from grpc import Channel, Server

from .scheduler_pb2_grpc import add_SchedulerServiceServicer_to_server, \
    SchedulerServiceServicer
from .message import Schedule, ScheduleRequest, ScheduleReply, \
    CancelRequest, CancelReply

__all__ = ["SchedulerService", "register_scheduler_service"]


class SchedulerService(SchedulerServiceServicer):
    def Schedule(self, request: ScheduleRequest, context) -> ScheduleReply:
        schedule = request.schedule
        job_id = self.schedule(
            schedule.schedule_id, schedule.user_id, schedule.org_id,
            schedule.workspace_id, schedule.experiment_id, schedule.token_id,
            schedule.token, schedule.scheduled, schedule.experiment,
            schedule.interval, schedule.repeat, schedule.cron,
            schedule.settings, schedule.configuration, schedule.secrets
        )
        return ScheduleReply(job_id=job_id)

    def Cancel(self, request: CancelRequest, context) -> CancelReply:
        self.cancel(request.job_id)
        return CancelReply()

    def schedule(self, schedule_id: str, user_id: str, org_id: str,
                 workspace_id: str, experiment_id: str, token_id: str,
                 token: str, scheduled: str, experiment: str, interval: int,
                 repeat: int, cron: str, settings: str, configuration: str,
                 secrets: str) -> str:
        raise NotImplementedError()

    def cancel(self, job_id: str) -> NoReturn:
        raise NotImplementedError()


def register_scheduler_service(service: SchedulerService, server: Server):
    """
    Register a scheduler service with the provided gRPC server.
    """
    add_SchedulerServiceServicer_to_server(service, server)
